import { SendInput, SendManualyInput, SendAutomaticInput, OTPSendResponse, VerifyRequest, OTPStatusRequest, OTPStatusResponse, OTPSendRequest, OTPError } from './types';
export { SendInput, SendManualyInput, SendAutomaticInput, OTPSendResponse, VerifyRequest, OTPStatusRequest, OTPStatusResponse, OTPSendRequest, OTPError };
export { OTPMethod, OTPStatus } from './types';
/**
 * Check whether an error is a gsOTP standard error or not<br>
 * These objects have two fields: `code` and `message`
 * @param error The error object to check
 * @returns `error` is a standard gsOTP error
 */
export declare function isGsOTPError(error: any): error is OTPError;
export declare class GsOTP<IsManual extends boolean = false> {
    private readonly apiKey;
    private readonly language;
    /**
     * @param apiKey Your API key in gsOTP.com.
     * @param manual Generate OTP code automatically or you gonna to enter it manually. <br>Default is `false`.
     * @param language Target language for showing error messages.
     */
    constructor(apiKey: string, manual?: IsManual, language?: string);
    private request;
    private send;
    /**
     * Send OTP Code via SMS
     * @param options Send options
     * @returns Reference ID
     */
    sendSMS(options: SendInput<IsManual>): Promise<bigint>;
    /**
     * Send OTP Code via IVR (Interactive voice response)
     * @param options Send options
     * @returns Reference ID
     */
    sendIVR(options: SendInput<IsManual>): Promise<bigint>;
    /**
     * Send OTP Code via Gap Messenger ([gap.im](https://gap.im))
     * @returns Reference ID
     */
    sendGapMessage(options: SendInput<IsManual>): Promise<bigint>;
    /**
     * Verify the user entered code.
     * @returns If the code is correct the promise resolves.
     */
    verify(options: VerifyRequest): Promise<void>;
    /**
     * Get status of the sent OTP.
     * @param referenceID
     */
    getStatus(options: OTPStatusRequest): Promise<OTPStatusResponse>;
}
